%define upstream_name    prefork
%define upstream_version 1.05

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 4

Summary:    Optimize module loading across forking and non-forking scenarios
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/authors/id/A/AD/ADAMK/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(List::Util) >= 0.180.0
BuildRequires: perl(Scalar::Util) >= 0.180.0
BuildRequires: perl(Test::More)
BuildRequires: perl(overload)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

Provides:   perl(prefork)

%description
The prefork pragma is intended to allow module writers to optimise
module loading for both scenarios with as little additional code as
possible.

The prefork.pm is intended to serve as a central and optional
marshalling point for state detection (are we running in procedural or
pre-forking mode) and to act as a relatively light-weight module loader.

Loaders and Forkers
prefork is intended to be used in two different ways.

The first is by a module that wants to indicate that another module
should be loaded before forking. This is known as a "Loader".

The other is a script or module that will be initiating the forking. It
will tell prefork.pm that it is either going to fork, or is about to
fork, and that the modules previously mentioned by the Loaders should be
loaded immediately.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%make_install

%files
%doc CONTRIBUTING Changes INSTALL LICENSE META.json META.yml MYMETA.yml README
%{perl_vendorlib}/prefork.pm
%{_mandir}/*/*

%changelog
* Fri Jun 27 2025 umeabot <umeabot> 1.50.0-4.mga10
+ Revision: 2205149
- Mageia 10 Mass Rebuild

* Mon Mar 21 2022 umeabot <umeabot> 1.50.0-3.mga9
+ Revision: 1811045
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 1.50.0-2.mga8
+ Revision: 1519992
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Tue Oct 30 2018 tv <tv> 1.50.0-1.mga7
+ Revision: 1326608
- update to 1.05

* Thu Sep 20 2018 umeabot <umeabot> 1.40.0-12.mga7
+ Revision: 1287506
- Mageia 7 Mass Rebuild

* Tue Oct 03 2017 tv <tv> 1.40.0-11.mga7
+ Revision: 1166367
- rebuild with fixed rpm for missing autodeps

* Wed Sep 27 2017 tv <tv> 1.40.0-10.mga7
+ Revision: 1160315
- add BR on perl(inc::Module::Install)

* Sun Jun 19 2016 pterjan <pterjan> 1.40.0-9.mga6
+ Revision: 1032692
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 1.40.0-8.mga6
+ Revision: 948910
- Mageia 6 Mass Rebuild

* Sun Oct 19 2014 umeabot <umeabot> 1.40.0-7.mga5
+ Revision: 788603
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 1.40.0-6.mga5
+ Revision: 743242
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.40.0-5.mga5
+ Revision: 687054
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 1.40.0-4.mga4
+ Revision: 516408
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 1.40.0-3.mga3
+ Revision: 375540
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jun 11 2011 spuhler <spuhler> 1.40.0-2.mga2
+ Revision: 103661
- increase rel for rebuild

* Tue Jan 25 2011 jquelin <jquelin> 1.40.0-1.mga1
+ Revision: 38395
- mageia rebuild
- imported package perl-prefork


* Thu Jul 23 2009 Jérôme Quelin <jquelin@mandriva.org> 1.40.0-1mdv2010.0
+ Revision: 398938
- update to 1.04
- using %%perl_convert_version
- fixed license field

* Wed May 06 2009 Jérôme Quelin <jquelin@mandriva.org> 1.03-1mdv2010.0
+ Revision: 372655
- update to new version 1.03
- adding explicit provides since lowercase ones are not automatically extracted

* Thu Aug 14 2008 Guillaume Rousse <guillomovitch@mandriva.org> 1.02-1mdv2009.0
+ Revision: 271884
- update to new version 1.02

* Thu Jul 31 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.01-4mdv2009.0
+ Revision: 258276
- rebuild

* Thu Jul 24 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.01-3mdv2009.0
+ Revision: 246336
- rebuild

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.01-1mdv2008.1
+ Revision: 136345
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Jul 02 2007 Olivier Thauvin <nanardon@mandriva.org> 1.01-1mdv2008.0
+ Revision: 46893
- 1.01


* Sun Jan 14 2007 Olivier Thauvin <nanardon@mandriva.org> 1.00-2mdv2007.0
+ Revision: 108465
- rebuild
- Import perl-prefork

* Sat Sep 24 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 1.00-1mdk
- New version

* Fri Jul 15 2005 Oden Eriksson <oeriksson@mandriva.com> 0.04-1mdk
- initial Mandriva package

